# {{ project_name }}

{{ description }}

## Installation

```bash
pip install -e .
```

## Development

Install development dependencies:

```bash
pip install -e ".[dev]"
```

## Running Tests

```bash
pytest
```

## Building the Package

```bash
python -m build
```

## License

This project is licensed under the {{ license }} License - see the [LICENSE](LICENSE) file for details.
