"""Version information for WRD package."""

# This version should match the version in pyproject.toml
__version__ = "0.1.2"
__author__ = "Tom Sapletta"
__license__ = "Apache-2.0"
__email__ = "info@softreck.dev"
